@@ -1,5 +1,5 @@
 name = "csinscapp"
-version = "0.1.5"
+version = "0.1.6"
 
 CLICK = 0
 MOUSE_DOWN = 1  
@@ -318,10 +318,10 @@ class Label (Control):
     else:    
       self.widget.style["display"] = "flex;" if self._visible == True else "none;"  
 
-class TextBox (Control):
+class Textbox (Control):
   def __init__(self, single_line = True, text = "", x = 0, y = 0, width = 64, height = 32):
     self.widget = gui.TextInput(single_line = single_line, width = width, height = height)  
-    super(TextBox, self).__init__(x, y, width, height)
+    super(Textbox, self).__init__(x, y, width, height)
   @property
   def data(self):
     return self.widget.get_value()
